OC.L10N.register(
    "dav",
    {
    "Calendar" : "Dagatal",
    "Tasks" : "Verkefni",
    "Personal" : "Einka",
    "{actor} created calendar {calendar}" : "{actor} bjó til dagatalið {calendar}",
    "You created calendar {calendar}" : "Þú bjóst til dagatalið {calendar}",
    "{actor} deleted calendar {calendar}" : "{actor} eyddi dagatalinu {calendar}",
    "You deleted calendar {calendar}" : "Þú eyddir dagatalinu {calendar}",
    "{actor} updated calendar {calendar}" : "{actor} uppfærði dagatalið {calendar}",
    "You updated calendar {calendar}" : "Þú uppfærðir dagatalið {calendar}",
    "{actor} restored calendar {calendar}" : "{actor} endurheimti dagatalið {calendar}",
    "You restored calendar {calendar}" : "Þú endurheimtir dagatalið {calendar}",
    "You shared calendar {calendar} as public link" : "Þú deildir dagatalinu {calendar} sem almenningstengli",
    "You removed public link for calendar {calendar}" : "Þú fjarlægðir almenningstengilinn fyrir dagatalið {calendar}",
    "{actor} shared calendar {calendar} with you" : "{actor} deildi dagatalinu {calendar} með þér",
    "You shared calendar {calendar} with {user}" : "Þú deildir dagatalinu {calendar} með {user}",
    "{actor} shared calendar {calendar} with {user}" : "{actor} deildi dagatalinu {calendar} með {user}",
    "{actor} unshared calendar {calendar} from you" : "{actor} tók af deilingu á dagatalinu {calendar} frá þér",
    "You unshared calendar {calendar} from {user}" : "Þú tókst af deilingu á dagatalinu {calendar} frá {user}",
    "{actor} unshared calendar {calendar} from {user}" : "{actor} tók af deilingu á dagatalinu {calendar} frá {user}",
    "{actor} unshared calendar {calendar} from themselves" : "{actor} tók af deilingu á dagatalinu {calendar} frá þeim sjálfum",
    "You shared calendar {calendar} with group {group}" : "Þú deildir dagatalinu {calendar} með hópnum {group}",
    "{actor} shared calendar {calendar} with group {group}" : "{actor} deildi dagatalinu {calendar} með hópnum {group}",
    "You unshared calendar {calendar} from group {group}" : "Þú tókst af deilingu á dagatalinu {calendar} frá hópnum {group}",
    "{actor} unshared calendar {calendar} from group {group}" : "{actor} tók af deilingu á dagatalinu {calendar} frá hópnum {group}",
    "Untitled event" : "Ónefndur atburður",
    "{actor} created event {event} in calendar {calendar}" : "{actor} bjó til atburðinn {event} í dagatalinu {calendar}",
    "You created event {event} in calendar {calendar}" : "Þú bjóst til atburðinn {event} í dagatalinu {calendar}",
    "{actor} deleted event {event} from calendar {calendar}" : "{actor} eyddi atburðinum {event} úr dagatalinu {calendar}",
    "You deleted event {event} from calendar {calendar}" : "Þú eyddir atburðinum {event} úr dagatalinu {calendar}",
    "{actor} updated event {event} in calendar {calendar}" : "{actor} uppfærði atburðinn {event} í dagatalinu {calendar}",
    "You updated event {event} in calendar {calendar}" : "Þú uppfærðir atburðinn {event} í dagatalinu {calendar}",
    "{actor} moved event {event} from calendar {sourceCalendar} to calendar {targetCalendar}" : "{actor} færði atburðinn {event} úr dagatalinu {sourceCalendar} yfir í dagatalið {targetCalendar}",
    "You moved event {event} from calendar {sourceCalendar} to calendar {targetCalendar}" : "Þú færðir atburðinn {event} úr dagatalinu {sourceCalendar} yfir í dagatalið {targetCalendar}",
    "{actor} restored event {event} of calendar {calendar}" : "{actor} endurheimti atburðinn {event} í dagatalinu {calendar}",
    "You restored event {event} of calendar {calendar}" : "Þú endurheimtir atburðinn {event} í dagatalinu {calendar}",
    "Busy" : "Upptekið",
    "{actor} created to-do {todo} in list {calendar}" : "{actor} bjó til verkefnið {todo} á listanum {calendar}",
    "You created to-do {todo} in list {calendar}" : "Þú bjóst til verkefnið {todo} á listanum {calendar}",
    "{actor} deleted to-do {todo} from list {calendar}" : "{actor} eyddi verkefninu {todo} af listanum {calendar}",
    "You deleted to-do {todo} from list {calendar}" : "Þú eyddir verkefninu {todo} af listanum {calendar}",
    "{actor} updated to-do {todo} in list {calendar}" : "{actor} uppfærði verkefnið {todo} á listanum {calendar}",
    "You updated to-do {todo} in list {calendar}" : "Þú uppfærðir verkefnið {todo} á listanum {calendar}",
    "{actor} solved to-do {todo} in list {calendar}" : "{actor} leysti verkefnið {todo} á listanum {calendar}",
    "You solved to-do {todo} in list {calendar}" : "Þú leystirverkefnið {todo} á listanum {calendar}",
    "{actor} reopened to-do {todo} in list {calendar}" : "{actor} opnaði aftur verkefnið {todo} á listanum {calendar}",
    "You reopened to-do {todo} in list {calendar}" : "Þú opnaðir aftur verkefnið {todo} á listanum {calendar}",
    "{actor} moved to-do {todo} from list {sourceCalendar} to list {targetCalendar}" : "{actor} færði verkefnið {todo} á listanum {sourceCalendar} yfir á listann {targetCalendar}",
    "You moved to-do {todo} from list {sourceCalendar} to list {targetCalendar}" : "Þú færðir verkefnið {todo} á listanum {sourceCalendar} yfir á listann {targetCalendar}",
    "Calendar, contacts and tasks" : "Dagatal, tengiliðir og verkefni",
    "A <strong>calendar</strong> was modified" : "<strong>Dagatali</strong> var breytt",
    "A calendar <strong>event</strong> was modified" : "<strong>Atburði</strong> dagatals var breytt",
    "A calendar <strong>to-do</strong> was modified" : "<strong>Verkþætti</strong> dagatals var breytt",
    "Contact birthdays" : "Afmælisdagar tengiliðar",
    "Death of %s" : "Andlát %s",
    "Untitled calendar" : "Ónefnt dagatal",
    "Calendar:" : "Dagatal:",
    "Date:" : "Dagsetning:",
    "Where:" : "Hvar:",
    "Description:" : "Lýsing:",
    "_%n year_::_%n years_" : ["%n ár","%n ár"],
    "_%n month_::_%n months_" : ["%n mánuður","%n mánuðir"],
    "_%n day_::_%n days_" : ["%n dagur","%n dagar"],
    "_%n hour_::_%n hours_" : ["%n klukkustund","%n klukkustundir"],
    "_%n minute_::_%n minutes_" : ["%n mínúta","%n mínútur"],
    "%s (in %s)" : "%s (í %s)",
    "%s (%s ago)" : "%s (%s síðan)",
    "Calendar: %s" : "Dagatal: %s",
    "Date: %s" : "Dagsetning: %s",
    "Description: %s" : "Lýsing: %s",
    "Where: %s" : "Hvar: %s",
    "%1$s via %2$s" : "%1$s með %2$s",
    "In the past on %1$s for the entire day" : "Í fortíðinni þann %1$s allan daginn",
    "_In a minute on %1$s for the entire day_::_In %n minutes on %1$s for the entire day_" : ["Eftir mínútu þann %1$s allan daginn","Eftir %n mínútur þann %1$s allan daginn"],
    "_In a hour on %1$s for the entire day_::_In %n hours on %1$s for the entire day_" : ["Eftir klukkustund þann %1$s allan daginn","Eftir %n klukkustundir þann %1$s allan daginn"],
    "_In a day on %1$s for the entire day_::_In %n days on %1$s for the entire day_" : ["Eftir dag þann %1$s allan daginn","Eftir %n daga þann %1$s allan daginn"],
    "_In a week on %1$s for the entire day_::_In %n weeks on %1$s for the entire day_" : ["Eftir viku þann %1$s allan daginn","Eftir %n vikur þann %1$s allan daginn"],
    "_In a month on %1$s for the entire day_::_In %n months on %1$s for the entire day_" : ["Eftir mánuð þann %1$s allan daginn","Eftir %n mánuði þann %1$s allan daginn"],
    "_In a year on %1$s for the entire day_::_In %n years on %1$s for the entire day_" : ["Eftir ár þann %1$s allan daginn","Eftir %n ár þann %1$s allan daginn"],
    "In the past on %1$s between %2$s - %3$s" : "Í fortíðinni þann %1$s milli %2$s - %3$s",
    "_In a minute on %1$s between %2$s - %3$s_::_In %n minutes on %1$s between %2$s - %3$s_" : ["Eftir mínútu þann %1$s milli %2$s - %3$s","Eftir %n mínútur þann %1$s milli %2$s - %3$s"],
    "_In a hour on %1$s between %2$s - %3$s_::_In %n hours on %1$s between %2$s - %3$s_" : ["Eftir klukkustund þann %1$s milli %2$s - %3$s","Eftir %n klukkustundir þann %1$s milli %2$s - %3$s"],
    "_In a day on %1$s between %2$s - %3$s_::_In %n days on %1$s between %2$s - %3$s_" : ["Eftir dag þann %1$s milli %2$s - %3$s","Eftir %n daga þann %1$s milli %2$s - %3$s"],
    "_In a week on %1$s between %2$s - %3$s_::_In %n weeks on %1$s between %2$s - %3$s_" : ["Eftir viku þann %1$s milli %2$s - %3$s","Eftir %n vikur þann %1$s milli %2$s - %3$s"],
    "_In a month on %1$s between %2$s - %3$s_::_In %n months on %1$s between %2$s - %3$s_" : ["Eftir mánuð þann %1$s milli %2$s - %3$s","Eftir %n mánuði þann %1$s milli %2$s - %3$s"],
    "_In a year on %1$s between %2$s - %3$s_::_In %n years on %1$s between %2$s - %3$s_" : ["Eftir ár þann %1$s milli %2$s - %3$s","Eftir %n ár þann %1$s milli %2$s - %3$s"],
    "Could not generate when statement" : "Mistókst að útbúa yfirlýsingu fyrir hvenær",
    "Every Day for the entire day" : "Á hverjum degi allan daginn",
    "Every Day for the entire day until %1$s" : "Á hverjum degi allan daginn til %1$s",
    "Every Day between %1$s - %2$s" : "Á hverjum degi milli %1$s - %2$s",
    "Every Day between %1$s - %2$s until %3$s" : "Á hverjum degi milli %1$s - %2$s til %3$s",
    "Every %1$d Days for the entire day" : "Á %1$d daga fresti allan daginn",
    "Every %1$d Days for the entire day until %2$s" : "Á %1$d daga fresti allan daginn til %2$s",
    "Every %1$d Days between %2$s - %3$s" : "Á %1$d daga fresti milli %2$s - %3$s",
    "Every %1$d Days between %2$s - %3$s until %4$s" : "Á %1$d daga fresti milli %2$s - %3$s til %4$s",
    "Could not generate event recurrence statement" : "Mistókst að útbúa yfirlýsingu fyrir næstu endurtekningu atburðar",
    "Every Week on %1$s for the entire day" : "Í hverri viku á %1$s allan daginn",
    "Every Week on %1$s for the entire day until %2$s" : "Í hverri viku á %1$s allan daginn til %2$s",
    "Every Week on %1$s between %2$s - %3$s" : "Í hverri viku á %1$s milli %3$s - %2$s",
    "Every Week on %1$s between %2$s - %3$s until %4$s" : "Í hverri viku á %1$s milli %2$s - %3$s til %4$s",
    "Every %1$d Weeks on %2$s for the entire day" : "Á %1$d vikna fresti á %2$s allan daginn",
    "Every %1$d Weeks on %2$s for the entire day until %3$s" : "Á %1$d vikna fresti á %2$s allan daginn til %3$s",
    "Every %1$d Weeks on %2$s between %3$s - %4$s" : "Á %1$d vikna fresti á %2$s milli %3$s - %4$s",
    "Every %1$d Weeks on %2$s between %3$s - %4$s until %5$s" : "Á %1$d vikna fresti á %2$s milli %3$s - %4$s til %5$s",
    "Every Month on the %1$s for the entire day" : "Í hverjum mánuði á %1$s allan daginn",
    "Every Month on the %1$s for the entire day until %2$s" : "Í hverjum mánuði á %1$s allan daginn til %2$s",
    "Every Month on the %1$s between %2$s - %3$s" : "Í hverjum mánuði á %1$s milli %2$s - %3$s",
    "Every Month on the %1$s between %2$s - %3$s until %4$s" : "Í hverjum mánuði á %1$s milli %2$s - %3$s til %4$s",
    "Every %1$d Months on the %2$s for the entire day" : "Á %1$d mánaða fresti á %2$s allan daginn",
    "Every %1$d Months on the %2$s for the entire day until %3$s" : "Á %1$d mánaða fresti á %2$s allan daginn til %3$s",
    "Every %1$d Months on the %2$s between %3$s - %4$s" : "Á %1$d mánaða fresti á %2$s milli %3$s - %4$s",
    "Every %1$d Months on the %2$s between %3$s - %4$s until %5$s" : "Á %1$d mánaða fresti á %2$s milli %3$s - %4$s til %5$s",
    "Every Year in %1$s on the %2$s for the entire day" : "Á hverju ári í %1$s þann %2$s allan daginn",
    "Every Year in %1$s on the %2$s for the entire day until %3$s" : "Á hverju ári í %1$s þann %2$s allan daginn til %3$s",
    "Every Year in %1$s on the %2$s between %3$s - %4$s" : "Á hverju ári í %1$s þann %2$s milli %3$s - %4$s",
    "Every Year in %1$s on the %2$s between %3$s - %4$s until %5$s" : "Á hverju ári í %1$s þann %2$s milli %3$s - %4$s til %5$s",
    "Every %1$d Years in %2$s on the %3$s for the entire day" : "Á %1$d ára fresti í %2$s þann %3$s allan daginn",
    "Every %1$d Years in %2$s on the %3$s for the entire day until %4$s" : "Á %1$d ára fresti í %2$s þann %3$s allan daginn til %4$s",
    "Every %1$d Years in %2$s on the %3$s between %4$s - %5$s" : "Á %1$d ára fresti í %2$s þann %3$s milli %4$s - %5$s",
    "Every %1$d Years in %2$s on the %3$s between %4$s - %5$s until %6$s" : "Á %1$d ára fresti í %2$s þann %3$s milli %4$s - %5$s til %6$s",
    "On specific dates for the entire day until %1$s" : "Á tilteknu dögum allan daginn til %1$s",
    "On specific dates between %1$s - %2$s until %3$s" : "Á tilteknum dögum frá %1$s - %2$s til %3$s",
    "In the past on %1$s" : "Í fortíðinni þann %1$s",
    "_In a minute on %1$s_::_In %n minutes on %1$s_" : ["Eftir mínútu þann %1$s","Eftir %n mínútur þann %1$s"],
    "_In a hour on %1$s_::_In %n hours on %1$s_" : ["Eftir klukkustund þann %1$s","Eftir %n klukkustundir þann %1$s"],
    "_In a day on %1$s_::_In %n days on %1$s_" : ["Eftir dag þann %1$s","Eftir %n daga þann %1$s"],
    "_In a week on %1$s_::_In %n weeks on %1$s_" : ["Eftir viku þann %1$s","Eftir %n vikur þann %1$s"],
    "_In a month on %1$s_::_In %n months on %1$s_" : ["Eftir mánuð þann %1$s","Eftir %n mánuði þann %1$s"],
    "_In a year on %1$s_::_In %n years on %1$s_" : ["Eftir ár þann %1$s","Eftir %n ár þann %1$s"],
    "In the past on %1$s then on %2$s" : "Í fortíðinni þann %1$s og síðan %2$s",
    "_In a minute on %1$s then on %2$s_::_In %n minutes on %1$s then on %2$s_" : ["Eftir mínútu þann %1$s og síðan þann %2$s","Eftir %n mínútur þann %1$s og síðan þann %2$s"],
    "_In a hour on %1$s then on %2$s_::_In %n hours on %1$s then on %2$s_" : ["Eftir klukkustund þann %1$s og síðan þann %2$s","Eftir %n klukkustundir þann %1$s og síðan þann %2$s"],
    "_In a day on %1$s then on %2$s_::_In %n days on %1$s then on %2$s_" : ["Eftir dag þann %1$s og síðan þann %2$s","Eftir %n daga þann %1$s og síðan þann %2$s"],
    "_In a week on %1$s then on %2$s_::_In %n weeks on %1$s then on %2$s_" : ["Eftir viku þann %1$s og síðan þann %2$s","Eftir %n vikur þann %1$s og síðan þann %2$s"],
    "_In a month on %1$s then on %2$s_::_In %n months on %1$s then on %2$s_" : ["Eftir mánuð þann %1$s og síðan þann %2$s","Eftir %n mánuði þann %1$s og síðan þann %2$s"],
    "_In a year on %1$s then on %2$s_::_In %n years on %1$s then on %2$s_" : ["Eftir ár þann %1$s og síðan þann %2$s","Eftir %n ár þann %1$s og síðan þann %2$s"],
    "In the past on %1$s then on %2$s and %3$s" : "Í fortíðinni þann %1$s og síðan %2$s og %3$s",
    "_In a minute on %1$s then on %2$s and %3$s_::_In %n minutes on %1$s then on %2$s and %3$s_" : ["Eftir mínútu þann %1$s og síðan þann %2$s og %3$s","Eftir %n mínútur þann %1$s og síðan þann %2$s og %3$s"],
    "_In a hour on %1$s then on %2$s and %3$s_::_In %n hours on %1$s then on %2$s and %3$s_" : ["Eftir klukkustund þann %1$s og síðan þann %2$s og %3$s","Eftir %n klukkustundir þann %1$s og síðan þann %2$s og %3$s"],
    "_In a day on %1$s then on %2$s and %3$s_::_In %n days on %1$s then on %2$s and %3$s_" : ["Eftir dag þann %1$s og síðan þann %2$s og %3$s","Eftir %n daga þann %1$s og síðan þann %2$s og %3$s"],
    "_In a week on %1$s then on %2$s and %3$s_::_In %n weeks on %1$s then on %2$s and %3$s_" : ["Eftir viku þann %1$s og síðan þann %2$s og %3$s","Eftir %n vikur þann %1$s og síðan þann %2$s og %3$s"],
    "_In a month on %1$s then on %2$s and %3$s_::_In %n months on %1$s then on %2$s and %3$s_" : ["Eftir mánuð þann %1$s og síðan þann %2$s og %3$s","Eftir %n mánuði þann %1$s og síðan þann %2$s og %3$s"],
    "_In a year on %1$s then on %2$s and %3$s_::_In %n years on %1$s then on %2$s and %3$s_" : ["Eftir ár þann %1$s og síðan þann %2$s og %3$s","Eftir %n ár þann %1$s og síðan þann %2$s og %3$s"],
    "Could not generate next recurrence statement" : "Mistókst að útbúa yfirlýsingu fyrir næstu endurtekningu",
    "Cancelled: %1$s" : "Hætt við: %1$s",
    "\"%1$s\" has been canceled" : "Hætt hefur verið við \"%1$s\"",
    "Re: %1$s" : "Svar: %1s",
    "%1$s has accepted your invitation" : "%1$s hefur samþykkt boð þitt",
    "%1$s has tentatively accepted your invitation" : "%1$s hefur samþykkt boð þitt með fyrirvara",
    "%1$s has declined your invitation" : "%1$s hafnaði boði þínu",
    "%1$s has responded to your invitation" : "%1$s hefur svarað boði þínu",
    "Invitation updated: %1$s" : "Boð uppfært: %1$s",
    "%1$s updated the event \"%2$s\"" : "%1$s uppfærði atburðinn \"%2$s\"",
    "Invitation: %1$s" : "Boð: %1$s",
    "%1$s would like to invite you to \"%2$s\"" : "%1$s vill fá að bjóða þér í \"%2$s\"",
    "Organizer:" : "Skipuleggjandi:",
    "Attendees:" : "Þáttakendur:",
    "Title:" : "Titill:",
    "When:" : "Hvenær:",
    "Location:" : "Staðsetning:",
    "Link:" : "Tengill:",
    "Occurring:" : "Gerist:",
    "Accept" : "Samþykkja",
    "Decline" : "Hafna",
    "More options …" : "Fleiri valkostir ...",
    "More options at %s" : "Fleiri valkostir á %s",
    "Monday" : "mánudag",
    "Tuesday" : "þriðjudag",
    "Wednesday" : "miðvikudag",
    "Thursday" : "fimmtudag",
    "Friday" : "föstudag",
    "Saturday" : "laugardag",
    "Sunday" : "sunnudag",
    "January" : "Janúar",
    "February" : "Febrúar",
    "March" : "Mars",
    "April" : "Apríl",
    "May" : "Maí",
    "June" : "Júní",
    "July" : "Júlí",
    "August" : "Ágúst",
    "September" : "September",
    "October" : "Október",
    "November" : "Nóvember",
    "December" : "Desember",
    "First" : "fyrsta",
    "Second" : "annan",
    "Third" : "þriðja",
    "Fourth" : "fjórða",
    "Fifth" : "fimmta",
    "Last" : "síðasta",
    "Second Last" : "næstsíðasta",
    "Third Last" : "þriðja síðasta",
    "Fourth Last" : "fjórða síðasta",
    "Fifth Last" : "fimmta síðasta",
    "Contacts" : "Tengiliðir",
    "{actor} created address book {addressbook}" : "{actor} útbjó nafnaskrána {addressbook}",
    "You created address book {addressbook}" : "Þú bjóst til nafnaskrána {addressbook}",
    "{actor} deleted address book {addressbook}" : "{actor} eyddi nafnaskránni {addressbook}",
    "You deleted address book {addressbook}" : "Þú eyddir nafnaskránni {addressbook}",
    "{actor} updated address book {addressbook}" : "{actor} uppfærði nafnaskrána {addressbook}",
    "You updated address book {addressbook}" : "Þú uppfærðir nafnaskrána {addressbook}",
    "{actor} shared address book {addressbook} with you" : "{actor} deildi nafnaskránni {addressbook} með þér",
    "You shared address book {addressbook} with {user}" : "Þú deildir nafnaskránni {addressbook} með {user}",
    "{actor} shared address book {addressbook} with {user}" : "{actor} deildi nafnaskránni {addressbook} með {user}",
    "{actor} unshared address book {addressbook} from you" : "{actor} hætti að deila nafnaskránni {addressbook} með þér",
    "You unshared address book {addressbook} from {user}" : "Þú hættir að deila nafnaskránni {addressbook} með {user}",
    "{actor} unshared address book {addressbook} from {user}" : "{actor} hætti að deila nafnaskránni {addressbook} með {user}",
    "{actor} unshared address book {addressbook} from themselves" : "{actor} hætti að deila nafnaskránni {addressbook} með sjálfum sér",
    "You shared address book {addressbook} with group {group}" : "Þú deildir nafnaskránni {addressbook} með hópnum {group}",
    "{actor} shared address book {addressbook} with group {group}" : "{actor} deildi nafnaskránni {addressbook} með hópnum {group}",
    "You unshared address book {addressbook} from group {group}" : "Þú hættir að deila nafnaskránni {addressbook} með hópnum {group}",
    "{actor} unshared address book {addressbook} from group {group}" : "{actor} hætti að deila nafnaskránni {addressbook} með hópnum {group}",
    "{actor} created contact {card} in address book {addressbook}" : "{actor} útbjó tengiliðinn {card} í nafnaskránni {addressbook}",
    "You created contact {card} in address book {addressbook}" : "Þú útbjóst tengiliðinn {card} í nafnaskránni {addressbook}",
    "{actor} deleted contact {card} from address book {addressbook}" : "{actor} eyddi tengiliðnum {card} úr nafnaskránni {addressbook}",
    "You deleted contact {card} from address book {addressbook}" : "Þú eyddir tengiliðnum {card} úr nafnaskránni {addressbook}",
    "{actor} updated contact {card} in address book {addressbook}" : "{actor} uppfærði tengiliðinn {card} í nafnaskránni {addressbook}",
    "You updated contact {card} in address book {addressbook}" : "Þú uppfærðir tengiliðinn {card} í nafnaskránni {addressbook}",
    "A <strong>contact</strong> or <strong>address book</strong> was modified" : "<strong>Tengilið</strong> eða <strong>nafnaskrá</strong> var breytt",
    "Accounts" : "Notandaaðgangar",
    "System address book which holds all accounts" : "Kerfisnafnaskrá sem inniheldur alla notendaaðganga",
    "File is not updatable: %1$s" : "Skráin er ekki uppfæranleg: %1$s",
    "Failed to get storage for file" : "Mistókst að fá geymslu fyrir skrá",
    "Could not write to final file, canceled by hook" : "Gat ekki skrifað í endanlega skrá, hætt við af tengikrækju",
    "Could not write file contents" : "Mistókst að skrifa innihald skrár",
    "_%n byte_::_%n bytes_" : ["%n bæti","%n bæti"],
    "Error while copying file to target location (copied: %1$s, expected filesize: %2$s)" : "Villa kom upp við að afrita skrá á áfangastað (afritað: %1$s, væntanleg skráarstærð: %2$s)",
    "Expected filesize of %1$s but read (from Nextcloud client) and wrote (to Nextcloud storage) %2$s. Could either be a network problem on the sending side or a problem writing to the storage on the server side." : "Átti von á skráarstærðinni %1$s en las (frá Nextcloud-biðlara) og skrifaði (í Nextcloud-geymslurými) %2$s. Gæti annað hvort verið vandamál í netkerfi varðandi sendingu eða vandamál við skrifun á netþjóni.",
    "Could not rename part file to final file, canceled by hook" : "Gat ekki endurnefnt hlutaskrá sem endanlega skrá, hætt við af tengikrækju",
    "Could not rename part file to final file" : "Gat ekki endurnefnt hlutaskrá sem endanlega skrá",
    "Failed to check file size: %1$s" : "Mistókst að athuga skráarstærð: %1$s",
    "Could not open file: %1$s, file does seem to exist" : "Gat ekki opnað skrá: %1$s, skráin virðist vera til.",
    "Could not open file: %1$s, file doesn't seem to exist" : "Gat ekki opnað skrá: %1$s, skráin virðist ekki vera til.",
    "Encryption not ready: %1$s" : "Dulritun ekki tilbúin: %1$s",
    "Failed to open file: %1$s" : "Mistókst að opna skrá: %1$s",
    "Failed to unlink: %1$s" : "Mistókst að aftengja: %1$s",
    "Failed to write file contents: %1$s" : "Mistókst að skrifa innihald skrár: %1$s",
    "File not found: %1$s" : "Skrá fannst ekki: %1$s",
    "Invalid target path" : "Ógild markslóð",
    "System is in maintenance mode." : "Kerfið er í viðhaldsham.",
    "Upgrade needed" : "Uppfærsla nauðsynleg",
    "Your %s needs to be configured to use HTTPS in order to use CalDAV and CardDAV with iOS/macOS." : "%s þarf að vera sett upp til að nota HTTPS til að CalDAV og CardDAV virki með iOS/macOS.",
    "Configures a CalDAV account" : "Setur upp CalDAV aðgang",
    "Configures a CardDAV account" : "Setur upp CardDAV aðgang",
    "Events" : "Atburðir",
    "Untitled task" : "Ónefnt verkefni",
    "Completed on %s" : "Lokið þann %s",
    "Due on %s by %s" : "Á að ljúka %s af %s",
    "Due on %s" : "Á að ljúka þann %s",
    "DAV system address book" : "DAV-kerfisnafnaskrá",
    "No outstanding DAV system address book sync." : "Engar eftirstandandi samstillingar við DAV-kerfisnafnaskrá.",
    "The DAV system address book sync has not run yet as your instance has more than 1000 users or because an error occurred. Please run it manually by calling \"occ dav:sync-system-addressbook\"." : "Samstilling við DAV-nafnaskrá kerfisins hefur ekki enn verið keyrð, þar sem tilvikið þitt er með fleiri en 1000 notendur eða að villa hefur komið upp. Keyrðu samstillinguna handvirkt með því að kalla á occ dav:sync-system-addressbook\".",
    "WebDAV endpoint" : "WebDAV-endapunktur",
    "Could not check that your web server is properly set up to allow file synchronization over WebDAV. Please check manually." : "Tókst ekki að athuga hvort vefþjónninn sé sett upp á réttan hátt til að leyfa samstillingu skráa í gegnum WebDAV. Athugaðu hvort svo sé.",
    "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken." : "Vefþjónninn er ekki enn sett upp á réttan hátt til að leyfa skráasamstillingu því WebDAV viðmótið virðist vera skemmt.",
    "Your web server is properly set up to allow file synchronization over WebDAV." : "Vefþjónninn þinn er settur upp á réttan hátt til að leyfa samstillingu skráa í gegnum WebDAV.",
    "Migrated calendar (%1$s)" : "Yfirfært dagatal (%1$s)",
    "Calendars including events, details and attendees" : "Dagatöl sem innihalda atburði, nánari upplýsingar og þátttakendur",
    "Contacts and groups" : "Tengiliðir og hópar",
    "WebDAV" : "WebDAV",
    "Absence saved" : "Fjarvera vistuð",
    "Failed to save your absence settings" : "Mistókst að vista fjarvistastillingar þínar",
    "Absence cleared" : "Fjarvera hreinsuð",
    "Failed to clear your absence settings" : "Mistókst að hreinsa fjarvistastillingar þínar",
    "First day" : "Fyrsta dag",
    "Last day (inclusive)" : "Síðasta dag (meðtalinn)",
    "Out of office replacement (optional)" : "Afleysing við fjarveru utan fyrirtækis (valfrjálst)",
    "Name of the replacement" : "Nafn þess sem tekur við í afleysingu",
    "No results." : "Engar niðurstöður.",
    "Start typing." : "Byrjaðu að skrifa.",
    "Short absence status" : "Staða stuttrar fjarveru",
    "Long absence Message" : "Skilaboð vegna langrar fjarveru",
    "Save" : "Vista",
    "Disable absence" : "Gera fjarveru óvirka",
    "Failed to load availability" : "Mistókst að hlaða inn lausum tímum",
    "Saved availability" : "Vistaði lausa tíma",
    "Failed to save availability" : "Mistókst að hlaða vista lausa tíma",
    "to" : "til",
    "Delete slot" : "Eyða tímahólfi",
    "No working hours set" : "Enginn vinnutími stilltur",
    "Add slot" : "Bæta við tímahólfi",
    "Weekdays" : "Virkir dagar",
    "Pick a start time for {dayName}" : "Veldu upphafstíma fyrir {dayName}",
    "Pick a end time for {dayName}" : "Veldu lokatíma fyrir {dayName}",
    "Automatically set user status to \"Do not disturb\" outside of availability to mute all notifications." : "Setja stöðu notenda sjálfkrafa á \"Ekki ónáða\" utan þess lausa tíma sem viðkomandi er tiltækur, til að þagga niður í öllum tilkynningum.",
    "Cancel" : "Hætta við",
    "Import" : "Flytja inn",
    "Error while saving settings" : "Villa við að vista stillingar",
    "Reset to default" : "Endurstilla á sjálfgefið",
    "Availability" : "Aðgengileiki",
    "If you configure your working hours, other people will see when you are out of office when they book a meeting." : "Ef þú stillir vinnutímana þína, geta aðrir séð hvenær þú sért fjarverandi þegar þeir bóka fundi með þér.",
    "Absence" : "Fjarverandi",
    "Configure your next absence period." : "Stilltu næsta fjarvistatímabilið þitt",
    "Also install the {calendarappstoreopen}Calendar app{linkclose}, or {calendardocopen}connect your desktop & mobile for syncing ↗{linkclose}." : "Settu líka upp {calendarappstoreopen}Calendar-forritið{linkclose}, eða {calendardocopen}-tengdu tölvuna þína & farsíma fyrir samstillingu ↗{linkclose}.",
    "Please make sure to properly set up {emailopen}the email server{linkclose}." : "Gakktu úr skugga um að {emailopen}póstþjóninn{linkclose} sé rétt uppsettur.",
    "Calendar server" : "Dagatalaþjónn",
    "Send invitations to attendees" : "Senda boð til þátttakenda",
    "Automatically generate a birthday calendar" : "Útbúa fæðingardagatal sjálfvirkt",
    "Birthday calendars will be generated by a background job." : "Fæðingardagatöl verða útbúin í bakvinnsluferli.",
    "Hence they will not be available immediately after enabling but will show up after some time." : "Þar með verða þau ekki tilbúin strax eftir að þetta er virkjað, heldur birtast þau eftir nokkurn tíma.",
    "Send notifications for events" : "Senda tilkynningar fyrir atburði",
    "Notifications are sent via background jobs, so these must occur often enough." : "Tilkynningar eru sendar í gegnum bakgrunnsverk, þannig að þær verða að gerast nógu oft.",
    "Send reminder notifications to calendar sharees as well" : "Senda einnig tilkynningar til þeirra sem deila dagatalinu",
    "Reminders are always sent to organizers and attendees." : "Áminningar eru alltaf sendar til skipuleggjenda og þátttakenda.",
    "Enable notifications for events via push" : "Senda tilkynningar fyrir atburði sem ýtitilkynningar",
    "There was an error updating your attendance status." : "Það kom upp villa við að uppfæra mætingarstöðu þína.",
    "Please contact the organizer directly." : "Hafðu samband beint við skipuleggjendurna.",
    "Are you accepting the invitation?" : "Ætlar þú að samþykkja boðið?",
    "Tentative" : "Bráðabirgða",
    "Your attendance was updated successfully." : "Mætingarstaða þín var uppfærð.",
    "Time zone:" : "Tímabelti:"
},
"nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");
